@@ -15,6 +15,7 @@ def generate_wrapper_from_adapter(adapter_class):
 class TapiocaAdapter:
     serializer_class = SimpleSerializer
     refresh_token = False
+    semaphore = 10
 
     def __init__(self, serializer_class=None, *args, **kwargs):
         if serializer_class:
@@ -48,6 +49,9 @@ class TapiocaAdapter:
     def get_api_root(self, api_params, **kwargs):
         return self.api_root
 
+    def get_resource_mapping(self, api_params, **kwargs):
+        return self.resource_mapping
+
     def fill_resource_template_url(self, template, url_params, **kwargs):
         if isinstance(template, str):
             return template.format(**url_params)
